package cn.iocoder.yudao.module.order.service.order;

import java.util.*;
import javax.validation.*;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.module.order.vo.orderItem.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderItem.OrderItemDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 订单项 Service 接口
 *
 * @author 系统管理员
 */
public interface OrderItemService extends IService<OrderItemDO> {

    /**
     * 创建订单项
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createOrderItem(@Valid OrderItemCreateReqVO createReqVO);

    /**
     * 更新订单项
     *
     * @param updateReqVO 更新信息
     */
    void updateOrderItem(@Valid OrderItemUpdateReqVO updateReqVO);

    /**
     * 更新订单项类型
     *
     * @param orderItemId 订单项ID
     * @param orderItemType 订单项类型
     */
    void updateOrderItemType(Long orderItemId, Integer orderItemType);

    /**
     * 删除订单项
     *
     * @param id 编号
     */
    void deleteOrderItem(Long id);

    /**
     * 获得订单项
     *
     * @param id 编号
     * @return 订单项
     */
    OrderItemDO getOrderItem(Long id);

    /**
     * 特需商品列表
     *
     * @param orderNo 订单号
     * @return 特价申请商品列表
     */
    List<OrderItemSpecialBackVO> specialApplyOrderItem(String orderNo);

    /**
     * 获得订单项列表
     *
     * @param ids 编号
     * @return 订单项列表
     */
    List<OrderItemDO> getOrderItemList(Collection<Long> ids);

    /**
     * 获得订单项分页
     *
     * @param page  分页查询
     * @param query 查询
     * @return 订单项分页
     */
    PageResult<OrderItemDO> getOrderItemPage(OrderItemQueryVO query, PageVO page);

    /**
     * 获得订单项列表, 用于 Excel 导出
     *
     * @param query 查询
     * @return 订单项列表
     */
    List<OrderItemDO> getOrderItemList(OrderItemQueryVO query);

    List<OrderItemDO> getOrderItemsByOrderId(List<Long> orderIdList);

    List<OrderItemBackVO> getOrderItemBackByOrderId(List<Long> orderIdList);

    /**
     * 更新订单项的入仓信息为空
     *
     * @param orderId
     * @param orderItemId
     */
    void updateOrderItemWarehouseInInfoToNull(Long orderId, Long orderItemId);


    /**
     * 更新订单项的入仓储位信息
     *
     * @param orderId
     * @param orderItemIdSet
     */
    void updateOrderItemWarehouseInInfoLocation(Long orderId, Set<Long> orderItemIdSet);


    /**
     * 根据订单找出所有订单项
     * @param orderIdList  订单列表
     * @return
     */
    List<OrderItemDO> getOrderItemListByOrderIdList(List<Long> orderIdList);
}
